# rv-ltl

`rv-ltl` is a Python package that implements Runtime Verification Linear Temporal Logic (RV-LTL), which was presented in A. Bauer, M. Leucker and C. Schallhart, "Comparing LTL Semantics for Runtime Verification," in Journal of Logic and Computation, vol. 20, no. 3, pp. 651-674, June 2010, doi: 10.1093/logcom/exn075.
